@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2022 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -110,6 +110,13 @@ if ($template->fields['taskcategories_id']) {
     }
 }
 
+if ($template->fields['groups_id_tech'] == 0) {
+    unset($template->fields['groups_id_tech']);
+}
+
+if ($template->fields['users_id_tech'] == 0) {
+    unset($template->fields['users_id_tech']);
+}
 
 // Return json response with the template fields
 echo json_encode($template->fields);
