@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -46,7 +46,7 @@ include('../inc/includes.php');
 if (isset($_GET["embed"]) && isset($_GET["dashboard"])) {
     $grid      = new Glpi\Dashboard\Grid($_GET["dashboard"]);
     $dashboard = $grid->getDashboard();
-    Html::zeroSecurityIframedHeader('central', 'central');
+    Html::zeroSecurityIframedHeader($grid->getDashboard()->getTitle(), 'central', 'central');
     echo $grid->embed($_REQUEST);
     Html::popFooter();
     exit;
