@@ -34,11 +34,11 @@
  */
 
 /**
- * Update from 10.0.0 to 10.0.1
+ * Update from 10.0.14 to 10.0.15
  *
  * @return bool for success (will die for most error)
  **/
-function update1000to1001()
+function update10014to10015()
 {
     /**
      * @var \DBmysql $DB
@@ -49,11 +49,11 @@ function update1000to1001()
     $updateresult       = true;
     $ADDTODISPLAYPREF   = [];
     $DELFROMDISPLAYPREF = [];
-    $update_dir = __DIR__ . '/update_10.0.0_to_10.0.1/';
+    $update_dir = __DIR__ . '/update_10.0.14_to_10.0.15/';
 
     //TRANS: %s is the number of new version
-    $migration->displayTitle(sprintf(__('Update to %s'), '10.0.1'));
-    $migration->setVersion('10.0.1');
+    $migration->displayTitle(sprintf(__('Update to %s'), '10.0.15'));
+    $migration->setVersion('10.0.15');
 
     $update_scripts = scandir($update_dir);
     foreach ($update_scripts as $update_script) {
@@ -64,35 +64,7 @@ function update1000to1001()
     }
 
     // ************ Keep it at the end **************
-    foreach ($ADDTODISPLAYPREF as $type => $tab) {
-        $rank = 1;
-        foreach ($tab as $newval) {
-            $DB->updateOrInsert(
-                "glpi_displaypreferences",
-                [
-                    'rank'      => $rank++
-                ],
-                Toolbox::addslashes_deep(
-                    [
-                        'users_id'  => "0",
-                        'itemtype'  => $type,
-                        'num'       => $newval,
-                    ]
-                )
-            );
-        }
-    }
-    foreach ($DELFROMDISPLAYPREF as $type => $tab) {
-        $DB->deleteOrDie(
-            'glpi_displaypreferences',
-            Toolbox::addslashes_deep(
-                [
-                    'itemtype'  => $type,
-                    'num'       => $tab
-                ]
-            )
-        );
-    }
+    $migration->updateDisplayPrefs($ADDTODISPLAYPREF, $DELFROMDISPLAYPREF);
 
     $migration->executeMigration();
 
