@@ -33,5 +33,14 @@
  * ---------------------------------------------------------------------
  */
 
-// Drop unexpected `['0' => 'system_user']` config added by buggy 9.5.x -> 10.0.0 migration.
-Config::deleteConfigurationValues('core', ['0']);
+/**
+ * @var \Migration $migration
+ */
+
+$migration->displayMessage('Add new configurations / user preferences');
+$migration->addConfig([
+    'timeline_action_btn_layout'   => 0,
+    'timeline_date_format'   => 0,
+]);
+$migration->addField('glpi_users', 'timeline_action_btn_layout', 'tinyint DEFAULT 0');
+$migration->addField('glpi_users', 'timeline_date_format', 'tinyint DEFAULT 0');
