@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -37,4 +37,5 @@
  * @var \Migration $migration
  */
 
-$migration->addField('glpi_transfers', 'keep_location', "int", ['value' => '1']);
+
+$migration->addField('glpi_transfers', 'lock_updated_fields', "int", ['value' => '0']);
