@@ -5,7 +5,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -66,7 +66,7 @@ GLPI.RichText.UserMention = class {
         this.editor.ui.registry.addAutocompleter(
             'user_mention',
             {
-                ch: '@',
+                trigger: '@',
                 minChars: 0,
                 fetch: function (pattern) {
                     return that.fetchItems(pattern);
