@@ -1,15 +1,9 @@
-/*!
- * TinyMCE Language Pack
- *
- * Copyright (c) 2022 Ephox Corporation DBA Tiny Technologies, Inc.
- * Licensed under the Tiny commercial license. See https://www.tiny.cloud/legal/
- */
-tinymce.addI18n('fi', {
+tinymce.addI18n("fi", {
     "Redo": "Tee uudelleen",
     "Undo": "Kumoa",
     "Cut": "Leikkaa",
     "Copy": "Kopioi",
-    "Paste": "Liitä",
+    "Paste": "Liit\xe4",
     "Select all": "Valitse kaikki",
     "New document": "Uusi asiakirja",
     "Ok": "Ok",
@@ -19,7 +13,7 @@ tinymce.addI18n('fi', {
     "Italic": "Kursivoitu",
     "Underline": "Alleviivaus",
     "Strikethrough": "Yliviivaus",
-    "Superscript": "Yläindeksi",
+    "Superscript": "Yl\xe4indeksi",
     "Subscript": "Alaindeksi",
     "Clear formatting": "Poista muotoilu",
     "Remove": "Poista",
@@ -28,13 +22,13 @@ tinymce.addI18n('fi', {
     "Align right": "Tasaa oikealle",
     "No alignment": "Ei tasausta",
     "Justify": "Tasaus",
-    "Bullet list": "Järjestämätön lista",
-    "Numbered list": "Järjestetty lista",
-    "Decrease indent": "Sisennä",
+    "Bullet list": "J\xe4rjest\xe4m\xe4t\xf6n lista",
+    "Numbered list": "J\xe4rjestetty lista",
+    "Decrease indent": "Sisenn\xe4",
     "Increase indent": "Loitonna",
     "Close": "Sulje",
     "Formats": "Muotoilut",
-    "Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.": "Selaimesi ei tue leikepöydän suoraa käyttämistä. Ole hyvä ja käytä näppäimistön Ctrl+X/C/V näppäinyhdistelmiä.",
+    "Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.": "Selaimesi ei tue leikep\xf6yd\xe4n suoraa k\xe4ytt\xe4mist\xe4. Ole hyv\xe4 ja k\xe4yt\xe4 n\xe4pp\xe4imist\xf6n Ctrl+X/C/V n\xe4pp\xe4inyhdistelmi\xe4.",
     "Headings": "Otsikot",
     "Heading 1": "Otsikko 1",
     "Heading 2": "Otsikko 2",
@@ -48,110 +42,110 @@ tinymce.addI18n('fi', {
     "Code": "Koodi",
     "Paragraph": "Kappale",
     "Blockquote": "Lohkolainaus",
-    "Inline": "Samalla rivillä",
+    "Inline": "Samalla rivill\xe4",
     "Blocks": "Lohkot",
-    "Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Liittäminen on nyt pelkässä tekstin tilassa. Sisältö liitetään nyt pelkkänä tekstinä, kunnes otat asetuksen pois päältä.",
+    "Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Liitt\xe4minen on nyt pelk\xe4ss\xe4 tekstin tilassa. Sis\xe4lt\xf6 liitet\xe4\xe4n nyt pelkk\xe4n\xe4 tekstin\xe4, kunnes otat asetuksen pois p\xe4\xe4lt\xe4.",
     "Fonts": "Fontti",
     "Font sizes": "Fonttikoot",
     "Class": "Luokka",
     "Browse for an image": "Selaa kuvia",
     "OR": "TAI",
-    "Drop an image here": "Pudota kuva tähän",
+    "Drop an image here": "Pudota kuva t\xe4h\xe4n",
     "Upload": "Vie",
     "Uploading image": "Ladataan kuvaa",
     "Block": "Lohko",
     "Align": "Tasaa",
     "Default": "Oletus",
-    "Circle": "Ympyrä",
-    "Disc": "Pyörylä",
-    "Square": "Neliö",
+    "Circle": "Ympyr\xe4",
+    "Disc": "Py\xf6ryl\xe4",
+    "Square": "Neli\xf6",
     "Lower Alpha": "Pienet kirjaimet",
-    "Lower Greek": "pienet kirjaimet: α, β, γ",
+    "Lower Greek": "pienet kirjaimet: \u03b1, \u03b2, \u03b3",
     "Lower Roman": "Numerot, alarivi",
     "Upper Alpha": "Isot kirjaimet",
-    "Upper Roman": "Numerot, ylärivi",
+    "Upper Roman": "Numerot, yl\xe4rivi",
     "Anchor...": "Ankkuri...",
     "Anchor": "Ankkuri",
     "Name": "Nimi",
     "ID": "ID",
-    "ID should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "ID:n tulisi alkaa kirjaimella, jota seuraa vain kirjaimia, numeroita, väliviivoja, pisteitä, kaksoispisteitä tai alaviivoja.",
-    "You have unsaved changes are you sure you want to navigate away?": "Sinulla on tallentamattomia muutoksia, haluatko varmasti siirtyä toiselle sivulle?",
+    "ID should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "ID:n tulisi alkaa kirjaimella, jota seuraa vain kirjaimia, numeroita, v\xe4liviivoja, pisteit\xe4, kaksoispisteit\xe4 tai alaviivoja.",
+    "You have unsaved changes are you sure you want to navigate away?": "Sinulla on tallentamattomia muutoksia, haluatko varmasti siirty\xe4 toiselle sivulle?",
     "Restore last draft": "Palauta aiempi luonnos",
     "Special character...": "Erikoismerkki...",
     "Special Character": "Erikoismerkki",
-    "Source code": "Lähdekoodi",
-    "Insert/Edit code sample": "Lisää/muokkaa koodiesimerkki",
+    "Source code": "L\xe4hdekoodi",
+    "Insert/Edit code sample": "Lis\xe4\xe4/muokkaa koodiesimerkki",
     "Language": "Kieli",
-    "Code sample...": "Koodinäyte...",
+    "Code sample...": "Koodin\xe4yte...",
     "Left to right": "Vasemmalta oikealle",
     "Right to left": "Oikealta vasemmalle",
     "Title": "Otsikko",
-    "Fullscreen": "Kokonäyttö",
+    "Fullscreen": "Kokon\xe4ytt\xf6",
     "Action": "Toiminto",
     "Shortcut": "Pikavalinta",
     "Help": "Ohje",
     "Address": "Osoite",
     "Focus to menubar": "Kohdistus valikkoon",
-    "Focus to toolbar": "Kohdistus työkalupalkkiin",
+    "Focus to toolbar": "Kohdistus ty\xf6kalupalkkiin",
     "Focus to element path": "Kohdistus elementin polkuun",
-    "Focus to contextual toolbar": "Kohdistus kontekstuaaliseen työkalupalkkiin",
-    "Insert link (if link plugin activated)": "Lisää linkki (jos linkki-liitännäinen aktiivinen)",
-    "Save (if save plugin activated)": "Tallenna (jos tallenna-liitännäinen aktiivinen)",
-    "Find (if searchreplace plugin activated)": "Etsi (jos etsikorvaa-liitännäinen aktiivinen)",
-    "Plugins installed ({0}):": "Asennetut liitännäiset ({0}):",
-    "Premium plugins:": "Premium-liitännäiset:",
-    "Learn more...": "Lisätietoja...",
-    "You are using {0}": "Käytät {0}",
+    "Focus to contextual toolbar": "Kohdistus kontekstuaaliseen ty\xf6kalupalkkiin",
+    "Insert link (if link plugin activated)": "Lis\xe4\xe4 linkki (jos linkki-liit\xe4nn\xe4inen aktiivinen)",
+    "Save (if save plugin activated)": "Tallenna (jos tallenna-liit\xe4nn\xe4inen aktiivinen)",
+    "Find (if searchreplace plugin activated)": "Etsi (jos etsikorvaa-liit\xe4nn\xe4inen aktiivinen)",
+    "Plugins installed ({0}):": "Asennetut liit\xe4nn\xe4iset ({0}):",
+    "Premium plugins:": "Premium-liit\xe4nn\xe4iset:",
+    "Learn more...": "Lis\xe4tietoja...",
+    "You are using {0}": "K\xe4yt\xe4t {0}",
     "Plugins": "Laajennukset",
-    "Handy Shortcuts": "Kätevät pikanäppäimet",
+    "Handy Shortcuts": "K\xe4tev\xe4t pikan\xe4pp\xe4imet",
     "Horizontal line": "Vaakasuora viiva",
-    "Insert/edit image": "Lisää kuva/muokkaa kuvaa",
+    "Insert/edit image": "Lis\xe4\xe4 kuva/muokkaa kuvaa",
     "Alternative description": "Vaihtoehtoinen kuvaus",
     "Accessibility": "Saavutettavuus",
     "Image is decorative": "Kuva on koristeellinen",
-    "Source": "Lähde",
+    "Source": "L\xe4hde",
     "Dimensions": "Mitat",
     "Constrain proportions": "Rajauksen mittasuhteet",
     "General": "Yleiset asetukset",
-    "Advanced": "Lisäasetukset",
+    "Advanced": "Lis\xe4asetukset",
     "Style": "Tyyli",
-    "Vertical space": "Pystysuuntainen väli",
-    "Horizontal space": "Vaakasuuntainen väli",
+    "Vertical space": "Pystysuuntainen v\xe4li",
+    "Horizontal space": "Vaakasuuntainen v\xe4li",
     "Border": "Reunus",
-    "Insert image": "Lisää kuva",
+    "Insert image": "Lis\xe4\xe4 kuva",
     "Image...": "Kuva...",
     "Image list": "Kuvaluettelo",
     "Resize": "Kuvan koon muutos",
-    "Insert date/time": "Lisää päivämäärä tai aika",
-    "Date/time": "Päivämäärä/aika",
-    "Insert/edit link": "Lisää linkki/muokkaa linkkiä",
-    "Text to display": "Näytettävä teksti",
+    "Insert date/time": "Lis\xe4\xe4 p\xe4iv\xe4m\xe4\xe4r\xe4 tai aika",
+    "Date/time": "P\xe4iv\xe4m\xe4\xe4r\xe4/aika",
+    "Insert/edit link": "Lis\xe4\xe4 linkki/muokkaa linkki\xe4",
+    "Text to display": "N\xe4ytett\xe4v\xe4 teksti",
     "Url": "Osoite",
     "Open link in...": "Avaa linkki...",
     "Current window": "Nykyinen ikkuna",
-    "None": "Ei mitään",
+    "None": "Ei mit\xe4\xe4n",
     "New window": "Uusi ikkuna",
     "Open link": "Avaa linkki",
     "Remove link": "Poista linkki",
     "Anchors": "Ankkurit",
     "Link...": "Linkki...",
-    "Paste or type a link": "Liitä tai kirjoita linkki",
-    "The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "Antamasi osoite näyttää olevan sähköpostiosoite. Haluatko lisätä osoitteeseen vaaditun mailto: -etuliitteen?",
-    "The URL you entered seems to be an external link. Do you want to add the required http:// prefix?": "Antamasi osoite näyttää olevan ulkoinen linkki. Haluatko lisätä osoitteeseen vaaditun http:// -etuliitteen?",
-    "The URL you entered seems to be an external link. Do you want to add the required https:// prefix?": "Syöttämäsi osoite näyttää olevan ulkoinen linkki. Haluatko lisätä vaaditun https://-etuliitteen?",
+    "Paste or type a link": "Liit\xe4 tai kirjoita linkki",
+    "The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "Antamasi osoite n\xe4ytt\xe4\xe4 olevan s\xe4hk\xf6postiosoite. Haluatko lis\xe4t\xe4 osoitteeseen vaaditun mailto: -etuliitteen?",
+    "The URL you entered seems to be an external link. Do you want to add the required http:// prefix?": "Antamasi osoite n\xe4ytt\xe4\xe4 olevan ulkoinen linkki. Haluatko lis\xe4t\xe4 osoitteeseen vaaditun http:// -etuliitteen?",
+    "The URL you entered seems to be an external link. Do you want to add the required https:// prefix?": "Sy\xf6tt\xe4m\xe4si osoite n\xe4ytt\xe4\xe4 olevan ulkoinen linkki. Haluatko lis\xe4t\xe4 vaaditun https://-etuliitteen?",
     "Link list": "Linkkiluettelo",
-    "Insert video": "Lisää video",
-    "Insert/edit video": "Lisää video/muokkaa videota",
-    "Insert/edit media": "Lisää media/muokkaa mediaa",
-    "Alternative source": "Vaihtoehtoinen lähde",
-    "Alternative source URL": "Vaihtoehtoinen lähde-URL",
+    "Insert video": "Lis\xe4\xe4 video",
+    "Insert/edit video": "Lis\xe4\xe4 video/muokkaa videota",
+    "Insert/edit media": "Lis\xe4\xe4 media/muokkaa mediaa",
+    "Alternative source": "Vaihtoehtoinen l\xe4hde",
+    "Alternative source URL": "Vaihtoehtoinen l\xe4hde-URL",
     "Media poster (Image URL)": "Median julkaisija (kuvan URL)",
-    "Paste your embed code below:": "Liitä upotuskoodisi alapuolelle:",
+    "Paste your embed code below:": "Liit\xe4 upotuskoodisi alapuolelle:",
     "Embed": "Upota",
     "Media...": "Media...",
-    "Nonbreaking space": "Sitova välilyönti",
+    "Nonbreaking space": "Sitova v\xe4lily\xf6nti",
     "Page break": "Sivunvaihto",
-    "Paste as text": "Liitä tekstinä",
+    "Paste as text": "Liit\xe4 tekstin\xe4",
     "Preview": "Esikatselu",
     "Print": "Tulosta",
     "Print...": "Tulosta",
@@ -164,49 +158,49 @@ tinymce.addI18n('fi', {
     "Next": "Seuraava",
     "Find and Replace": "Etsi ja korvaa",
     "Find and replace...": "Etsi ja korvaa...",
-    "Could not find the specified string.": "Haettua merkkijonoa ei löytynyt.",
+    "Could not find the specified string.": "Haettua merkkijonoa ei l\xf6ytynyt.",
     "Match case": "Sama kirjainkoko",
     "Find whole words only": "Etsi vain kokonaisia sanoja",
     "Find in selection": "Etsi valinnasta",
-    "Insert table": "Lisää taulukko",
+    "Insert table": "Lis\xe4\xe4 taulukko",
     "Table properties": "Taulukon ominaisuudet",
     "Delete table": "Poista taulukko",
     "Cell": "Solu",
     "Row": "Rivi",
     "Column": "Sarake",
     "Cell properties": "Solun ominaisuudet",
-    "Merge cells": "Yhdistä solut",
+    "Merge cells": "Yhdist\xe4 solut",
     "Split cell": "Jaa solu",
-    "Insert row before": "Lisää rivi ennen",
-    "Insert row after": "Lisää rivi jälkeen",
+    "Insert row before": "Lis\xe4\xe4 rivi ennen",
+    "Insert row after": "Lis\xe4\xe4 rivi j\xe4lkeen",
     "Delete row": "Poista rivi",
     "Row properties": "Rivin ominaisuudet",
     "Cut row": "Leikkaa rivi",
     "Cut column": "Leikkaa sarake",
     "Copy row": "Kopioi rivi",
     "Copy column": "Kopioi sarake",
-    "Paste row before": "Liitä rivi ennen",
-    "Paste column before": "Liitä sarake ennen",
-    "Paste row after": "Liitä rivi jälkeen",
-    "Paste column after": "Liitä sarake jälkeen",
-    "Insert column before": "Lisää sarake ennen",
-    "Insert column after": "Lisää sarake jälkeen",
+    "Paste row before": "Liit\xe4 rivi ennen",
+    "Paste column before": "Liit\xe4 sarake ennen",
+    "Paste row after": "Liit\xe4 rivi j\xe4lkeen",
+    "Paste column after": "Liit\xe4 sarake j\xe4lkeen",
+    "Insert column before": "Lis\xe4\xe4 sarake ennen",
+    "Insert column after": "Lis\xe4\xe4 sarake j\xe4lkeen",
     "Delete column": "Poista sarake",
     "Cols": "Sarakkeet",
     "Rows": "Rivit",
     "Width": "Leveys",
     "Height": "Korkeus",
-    "Cell spacing": "Solun väli",
-    "Cell padding": "Solun tyhjä tila",
-    "Row clipboard actions": "Rivin leikepöytätoiminnot",
-    "Column clipboard actions": "Sarakkeen leikepöytätoiminnot",
+    "Cell spacing": "Solun v\xe4li",
+    "Cell padding": "Solun tyhj\xe4 tila",
+    "Row clipboard actions": "Rivin leikep\xf6yt\xe4toiminnot",
+    "Column clipboard actions": "Sarakkeen leikep\xf6yt\xe4toiminnot",
     "Table styles": "Taulukon tyylit",
     "Cell styles": "Solun tyylit",
     "Column header": "Sarakkeen otsikko",
     "Row header": "Rivin otsikko",
     "Table caption": "Taulukon selitysteksti",
     "Caption": "Seloste",
-    "Show caption": "Näytä kuvateksti",
+    "Show caption": "N\xe4yt\xe4 kuvateksti",
     "Left": "Vasen",
     "Center": "Keskitetty",
     "Right": "Oikea",
@@ -215,17 +209,17 @@ tinymce.addI18n('fi', {
     "Alignment": "Tasaus",
     "Horizontal align": "Vaakasuuntainen tasaus",
     "Vertical align": "Pystysuuntainen tasaus",
-    "Top": "Ylä",
+    "Top": "Yl\xe4",
     "Middle": "Keski",
     "Bottom": "Ala",
     "Header cell": "Otsikkosolu",
-    "Row group": "Riviryhmä",
-    "Column group": "Sarakeryhmä",
+    "Row group": "Riviryhm\xe4",
+    "Column group": "Sarakeryhm\xe4",
     "Row type": "Rivityyppi",
-    "Header": "Ylätunniste",
+    "Header": "Yl\xe4tunniste",
     "Body": "Runko",
     "Footer": "Alatunniste",
-    "Border color": "Reunuksen väri",
+    "Border color": "Reunuksen v\xe4ri",
     "Solid": "Yksinkertainen",
     "Dotted": "Pisteet",
     "Dashed": "Katkoviiva",
@@ -235,20 +229,20 @@ tinymce.addI18n('fi', {
     "Inset": "Upotettu",
     "Outset": "Korotettu",
     "Hidden": "Piilotettu",
-    "Insert template...": "Lisää malli...",
+    "Insert template...": "Lis\xe4\xe4 malli...",
     "Templates": "Mallit",
     "Template": "Malli",
-    "Insert Template": "Lisää malli",
-    "Text color": "Tekstin väri",
-    "Background color": "Taustan väri",
+    "Insert Template": "Lis\xe4\xe4 malli",
+    "Text color": "Tekstin v\xe4ri",
+    "Background color": "Taustan v\xe4ri",
     "Custom...": "Mukautettu...",
-    "Custom color": "Mukautettu väri",
-    "No color": "Ei väriä",
-    "Remove color": "Poista väri",
-    "Show blocks": "Näytä lohkot",
-    "Show invisible characters": "Näytä näkymättömät merkit",
-    "Word count": "Sanamäärä",
-    "Count": "Määrä",
+    "Custom color": "Mukautettu v\xe4ri",
+    "No color": "Ei v\xe4ri\xe4",
+    "Remove color": "Poista v\xe4ri",
+    "Show blocks": "N\xe4yt\xe4 lohkot",
+    "Show invisible characters": "N\xe4yt\xe4 n\xe4kym\xe4tt\xf6m\xe4t merkit",
+    "Word count": "Sanam\xe4\xe4r\xe4",
+    "Count": "M\xe4\xe4r\xe4",
     "Document": "Tiedosto",
     "Selection": "Valinta",
     "Words": "Sanaa",
@@ -256,13 +250,13 @@ tinymce.addI18n('fi', {
     "{0} words": "{0} sanaa",
     "File": "Tiedosto",
     "Edit": "Muokkaa",
-    "Insert": "Lisää",
-    "View": "Näytä",
+    "Insert": "Lis\xe4\xe4",
+    "View": "N\xe4yt\xe4",
     "Format": "Muotoilu",
     "Table": "Taulukko",
-    "Tools": "Työkalut",
+    "Tools": "Ty\xf6kalut",
     "Powered by {0}": "Tarjoaja: {0}",
-    "Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Rikastetun tekstin alue. Paina ALT-F9 valikkoon. Paina ALT-F10 työkaluriviin. Paina ALT-0 ohjeeseen.",
+    "Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Rikastetun tekstin alue. Paina ALT-F9 valikkoon. Paina ALT-F10 ty\xf6kaluriviin. Paina ALT-0 ohjeeseen.",
     "Image title": "Kuvan otsikko",
     "Border width": "Reunuksen leveys",
     "Border style": "Reunuksen tyyli",
@@ -272,11 +266,11 @@ tinymce.addI18n('fi', {
     "To open the popup, press Shift+Enter": "Avaa ponnahdusikkuna painamalla Shift+Enter",
     "Rich Text Area": "Rikastetun tekstin alue",
     "Rich Text Area. Press ALT-0 for help.": "Rikastetun tekstin alue. Avaa ohje painamalla ALT-0.",
-    "System Font": "Järjestelmäfontti",
-    "Failed to upload image: {0}": "Kuvan lataus epäonnistui: {0}",
-    "Failed to load plugin: {0} from url {1}": "Liitännäisen lataus epäonnistui: {0} url:stä {1}",
-    "Failed to load plugin url: {0}": "Liitännäisen url:n lataus epäonnistui: {0}",
-    "Failed to initialize plugin: {0}": "Liitännäisen alustus epäonnistui: {0}",
+    "System Font": "J\xe4rjestelm\xe4fontti",
+    "Failed to upload image: {0}": "Kuvan lataus ep\xe4onnistui: {0}",
+    "Failed to load plugin: {0} from url {1}": "Liit\xe4nn\xe4isen lataus ep\xe4onnistui: {0} url:st\xe4 {1}",
+    "Failed to load plugin url: {0}": "Liit\xe4nn\xe4isen url:n lataus ep\xe4onnistui: {0}",
+    "Failed to initialize plugin: {0}": "Liit\xe4nn\xe4isen alustus ep\xe4onnistui: {0}",
     "example": "esimerkki",
     "Search": "Etsi",
     "All": "Kaikki",
@@ -287,7 +281,7 @@ tinymce.addI18n('fi', {
     "Extended Latin": "Laajennettu latina",
     "Symbols": "Symbolit",
     "Arrows": "Nuolet",
-    "User Defined": "Käyttäjämääritetty",
+    "User Defined": "K\xe4ytt\xe4j\xe4m\xe4\xe4ritetty",
     "dollar sign": "dollarimerkki",
     "currency sign": "valuuttamerkki",
     "euro-currency sign": "eurovaluuttamerkki",
@@ -328,40 +322,40 @@ tinymce.addI18n('fi', {
     "Loading emojis...": "Ladataan emojeita...",
     "Could not load emojis": "Emojeita ei voitu ladata",
     "People": "Ihmiset",
-    "Animals and Nature": "Eläimet ja luonto",
+    "Animals and Nature": "El\xe4imet ja luonto",
     "Food and Drink": "Ruoka ja juoma",
     "Activity": "Aktiviteetit",
     "Travel and Places": "Matkailu ja paikat",
     "Objects": "Esineet",
     "Flags": "Liput",
-    "Characters": "Merkkiä",
-    "Characters (no spaces)": "Merkkiä (ilman välilyöntejä)",
-    "{0} characters": "{0} merkkiä",
-    "Error: Form submit field collision.": "Virhe: lomakkeen lähetyskentän törmäys.",
-    "Error: No form element found.": "Virhe: muotoelementtiä ei löytynyt.",
-    "Color swatch": "Värinäyte",
-    "Color Picker": "Värivalitsin",
-    "Invalid hex color code: {0}": "Kelvoton heksavärikoodi: {0}",
-    "Invalid input": "Kelvoton syöte",
+    "Characters": "Merkki\xe4",
+    "Characters (no spaces)": "Merkki\xe4 (ilman v\xe4lily\xf6ntej\xe4)",
+    "{0} characters": "{0} merkki\xe4",
+    "Error: Form submit field collision.": "Virhe: lomakkeen l\xe4hetyskent\xe4n t\xf6rm\xe4ys.",
+    "Error: No form element found.": "Virhe: muotoelementti\xe4 ei l\xf6ytynyt.",
+    "Color swatch": "V\xe4rin\xe4yte",
+    "Color Picker": "V\xe4rivalitsin",
+    "Invalid hex color code: {0}": "Kelvoton heksav\xe4rikoodi: {0}",
+    "Invalid input": "Kelvoton sy\xf6te",
     "R": "P",
     "Red component": "Punainen komponentti",
     "G": "V",
-    "Green component": "Vihreä komponentti",
+    "Green component": "Vihre\xe4 komponentti",
     "B": "S",
     "Blue component": "Sininen komponentti",
     "#": "#",
-    "Hex color code": "Heksavärikoodi",
-    "Range 0 to 255": "Välillä 0–255",
+    "Hex color code": "Heksav\xe4rikoodi",
+    "Range 0 to 255": "V\xe4lill\xe4 0\u2013255",
     "Turquoise": "Turkoosi",
-    "Green": "Vihreä",
+    "Green": "Vihre\xe4",
     "Blue": "Sininen",
     "Purple": "Purppura",
     "Navy Blue": "Laivastonsininen",
     "Dark Turquoise": "Tumma turkoosi",
-    "Dark Green": "Tumma vihreä",
+    "Dark Green": "Tumma vihre\xe4",
     "Medium Blue": "Keskitumma sininen",
     "Medium Purple": "Keskitumma purppura",
-    "Midnight Blue": "keskiyön sininen",
+    "Midnight Blue": "keskiy\xf6n sininen",
     "Yellow": "Keltainen",
     "Orange": "Oranssi",
     "Red": "Punainen",
@@ -372,7 +366,7 @@ tinymce.addI18n('fi', {
     "Dark Red": "Tumma punainen",
     "Medium Gray": "Keskiharmaa",
     "Dark Gray": "Tummanharmaa",
-    "Light Green": "Vaaleanvihreä",
+    "Light Green": "Vaaleanvihre\xe4",
     "Light Yellow": "Vaaleankeltainen",
     "Light Red": "Vaaleanpunainen",
     "Light Purple": "Liila",
@@ -381,7 +375,7 @@ tinymce.addI18n('fi', {
     "Dark Blue": "Tummansininen",
     "Black": "Musta",
     "White": "Valkoinen",
-    "Switch to or from fullscreen mode": "Vaihda kokonäyttöön tai kokonäytöstä",
+    "Switch to or from fullscreen mode": "Vaihda kokon\xe4ytt\xf6\xf6n tai kokon\xe4yt\xf6st\xe4",
     "Open help dialog": "Avaa ohjeen valintaikkuna",
     "history": "historia",
     "styles": "tyylit",
@@ -390,14 +384,14 @@ tinymce.addI18n('fi', {
     "indentation": "sisennys",
     "Font": "Fontti",
     "Size": "Koko",
-    "More...": "Lisää...",
+    "More...": "Lis\xe4\xe4...",
     "Select...": "Valitse...",
     "Preferences": "Asetukset",
-    "Yes": "Kyllä",
+    "Yes": "Kyll\xe4",
     "No": "Ei",
-    "Keyboard Navigation": "Navigointi näppäimistöllä",
+    "Keyboard Navigation": "Navigointi n\xe4pp\xe4imist\xf6ll\xe4",
     "Version": "Versio",
-    "Code view": "Koodinäkymä",
+    "Code view": "Koodin\xe4kym\xe4",
     "Open popup menu for split buttons": "Avaa ponnahdusikkuna jaetuille napeille",
     "List Properties": "Listan ominaisuudet",
     "List properties...": "Listan ominaisuudet...",
@@ -405,8 +399,8 @@ tinymce.addI18n('fi', {
     "Line height": "Tekstirivin korkeus",
     "Dropped file type is not supported": "Pudotettu tiedostotyyppi ei ole tuettu",
     "Loading...": "Ladataan...",
-    "ImageProxy HTTP error: Rejected request": "ImageProxy HTTP-virhe: Pyyntö hylättiin",
-    "ImageProxy HTTP error: Could not find Image Proxy": "ImageProxy HTTP-virhe: Kuvaproxyä ei löytynyt",
-    "ImageProxy HTTP error: Incorrect Image Proxy URL": "ImageProxy HTTP-virhe: Väärä kuvaproxyn osoite",
+    "ImageProxy HTTP error: Rejected request": "ImageProxy HTTP-virhe: Pyynt\xf6 hyl\xe4ttiin",
+    "ImageProxy HTTP error: Could not find Image Proxy": "ImageProxy HTTP-virhe: Kuvaproxy\xe4 ei l\xf6ytynyt",
+    "ImageProxy HTTP error: Incorrect Image Proxy URL": "ImageProxy HTTP-virhe: V\xe4\xe4r\xe4 kuvaproxyn osoite",
     "ImageProxy HTTP error: Unknown ImageProxy error": "ImageProxy HTTP-virhe: Tuntematon ImageProxy-virhe"
 });
\ No newline at end of file
