@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -937,13 +937,13 @@ abstract class CommonTreeDropdown extends CommonDropdown
 
     public function import(array $input)
     {
-
-        if (isset($input['name'])) {
-            return parent::import($input);
+        if (empty($input['name']) && empty($input['completename'])) {
+            return -1;
         }
 
-        if (!isset($input['completename']) || empty($input['completename'])) {
-            return -1;
+        if (empty($input['completename'])) {
+            $input['completename'] = $input['name'];
+            unset($input['name']);
         }
 
        // Import a full tree from completename
