@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -411,18 +411,24 @@ class Computer_Item extends CommonDBRelation
                 $header_bottom .=  "</th>";
             }
 
-            $header_end .= "<th>" . _n('Type', 'Types', 1) . "</th>";
+            $header_end .= "<th>" . __('Item type') . "</th>";
             $header_end .= "<th>" . __('Name') . "</th>";
             $header_end .= "<th>" . __('Automatic inventory') . "</th>";
             $header_end .= "<th>" . Entity::getTypeName(1) . "</th>";
             $header_end .= "<th>" . __('Serial number') . "</th>";
             $header_end .= "<th>" . __('Inventory number') . "</th>";
+            $header_end .= "<th>" . _n('Type', 'Types', 1) . "</th>";
             $header_end .= "</tr>";
             echo $header_begin . $header_top . $header_end;
 
             foreach ($datas as $data) {
                 $linkname = $data["name"];
                 $itemtype = $data['assoc_itemtype'];
+
+                $type_class = $itemtype . "Type";
+                $type_table = getTableForItemType($type_class);
+                $type_field = getForeignKeyFieldForTable($type_table);
+
                 if ($_SESSION["glpiis_ids_visible"] || empty($data["name"])) {
                     $linkname = sprintf(__('%1$s (%2$s)'), $linkname, $data["id"]);
                 }
@@ -451,6 +457,11 @@ class Computer_Item extends CommonDBRelation
                    (isset($data["serial"]) ? "" . $data["serial"] . "" : "-") . "</td>";
                 echo "<td>" .
                    (isset($data["otherserial"]) ? "" . $data["otherserial"] . "" : "-") . "</td>";
+                echo "<td>" .
+                    (isset($data[$type_field]) ? "" . Dropdown::getDropdownName(
+                        $type_table,
+                        $data[$type_field]
+                    ) . "" : "-") . "</td>";
                 echo "</tr>";
             }
             echo $header_begin . $header_bottom . $header_end;
@@ -693,7 +704,7 @@ class Computer_Item extends CommonDBRelation
         $fromtype,
         $myname,
         $entity_restrict = -1,
-        $onlyglobal = 0,
+        $onlyglobal = false,
         $used = []
     ) {
         /** @var array $CFG_GLPI */
@@ -749,7 +760,7 @@ class Computer_Item extends CommonDBRelation
         $fromtype,
         $myname,
         $entity_restrict = -1,
-        $onlyglobal = 0,
+        $onlyglobal = false,
         $used = []
     ) {
         /** @var array $CFG_GLPI */
@@ -785,7 +796,8 @@ class Computer_Item extends CommonDBRelation
         /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
-       // can exists for Template
+        // can exists for Template
+        /** @var CommonDBTM $item */
         if ($item->can($item->getField('id'), READ)) {
             $nb = 0;
             $canview = false;
@@ -874,11 +886,11 @@ class Computer_Item extends CommonDBRelation
                 'GROUP' => 'itemtype'
             ]);
 
-            while ($data = $iterator->next()) {
+            foreach ($iterator as $data) {
                 if (!class_exists($data['itemtype'])) {
                     continue;
                 }
-                if (countElementsInTable($data['itemtype']::getTable(), ['id' => $data['ids'], 'NOT' => ['entities_id' => $entities]]) > 0) {
+                if (countElementsInTable($data['itemtype']::getTable(), ['id' => explode(',', $data['ids']), 'NOT' => ['entities_id' => $entities]]) > 0) {
                     return false;
                 }
             }
