@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @copyright 2010-2022 by the FusionInventory Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
@@ -246,11 +246,6 @@ abstract class MainAsset extends InventoryAsset
         /** @var \DBmysql $DB */
         global $DB;
 
-        if ($this->isPartial()) {
-            unset($val->users_id);
-            return;
-        }
-
         if (property_exists($val, 'users_id')) {
             if ($val->users_id == '') {
                 unset($val->users_id);
