@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @copyright 2010-2022 by the FusionInventory Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
@@ -138,6 +138,9 @@ class NetworkEquipment extends MainAsset
                 $stack->$model_field = $switch->model;
                 $stack->description = $stack->name . ' - ' . ($switch->name ?? $switch->description);
                 $stack->name = $stack->name . ' - ' . ($switch->name ?? $switch->description);
+                if (($switch->name ?? $switch->description) != $switch->stack_number ?? '') {
+                    $stack->name .= ' - ' . $switch->stack_number;
+                }
                 $stack->stack_number = $switch->stack_number ?? null;
                 $this->data[] = $stack;
             }
