@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -290,7 +290,8 @@ class Inventory
                 //if inventory is not partial, we consider following properties are empty if not present; so they'll be removed
                 $empty_props = [
                     'virtualmachines',
-                    'remote_mgmt'
+                    'remote_mgmt',
+                    'monitors'
                 ];
             }
 
@@ -573,7 +574,7 @@ class Inventory
      */
     final public function processInventoryData()
     {
-       //map existing keys in inventory format to their respective Inventory\Asset class if needed.
+        //map existing keys in inventory format to their respective Inventory\Asset class if needed.
         foreach ($this->data as $key => &$value) {
             $assettype = false;
 
