@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -198,7 +198,7 @@ class Migration
        // Do not log if more than 3 log error
         if (
             $this->log_errors < 3
-            && !Toolbox::logInFile($log_file_name, $message . ' @\n', true)
+            && !Toolbox::logInFile($log_file_name, $message . "\n", true)
         ) {
             $this->log_errors++;
         }
@@ -1716,6 +1716,25 @@ class Migration
                     'itemtype' => $itemtype,
                     'num'      => $old_search_opt
                 ]);
+
+                // Update template fields
+                if (is_a($itemtype, 'CommonITILObject', true)) {
+                    $tables = [
+                        'glpi_' . strtolower($itemtype) . 'templatehiddenfields',
+                        'glpi_' . strtolower($itemtype) . 'templatemandatoryfields',
+                        'glpi_' . strtolower($itemtype) . 'templatepredefinedfields',
+                    ];
+                    foreach ($tables as $table) {
+                        if (!$DB->tableExists($table)) {
+                            continue;
+                        }
+                        $DB->updateOrDie($table, [
+                            'field' => $new_search_opt
+                        ], [
+                            'field' => $old_search_opt
+                        ]);
+                    }
+                }
             }
         }
 
