@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -670,16 +670,19 @@ class NetworkPort extends CommonDBChild
         $itemtype = $item->getType();
         $items_id = $item->getField('id');
 
+        $netport = new self();
+        $netport_table = $netport->getTable();
+
         //no matter if the main item is dynamic,
         //deleted and dynamic networkport are displayed from lock tab
         //deleted and non dynamic networkport are always displayed (with is_deleted column)
         $deleted_criteria = [
             'OR'  => [
                 'AND' => [
-                    "is_deleted" => 0,
-                    "is_dynamic" => 1
+                    "$netport_table.is_deleted" => 0,
+                    "$netport_table.is_dynamic" => 1
                 ],
-                "is_dynamic" => 0
+                "$netport_table.is_dynamic" => 0
             ]
         ];
 
@@ -690,8 +693,6 @@ class NetworkPort extends CommonDBChild
             return false;
         }
 
-        $netport = new self();
-
         if (($itemtype == 'NetworkPort') || ($withtemplate == 2)) {
             $canedit = false;
         } else {
@@ -724,21 +725,25 @@ class NetworkPort extends CommonDBChild
         }
 
         $criteria = [
-            'FROM'   => $netport->getTable(),
+            'FROM'   => $netport_table,
             'WHERE'  => [
-                'items_id'  => $item->getID(),
-                'itemtype'  => $item->getType(), [
+                "$netport_table.items_id"  => $item->getID(),
+                "$netport_table.itemtype"  => $item->getType(), [
                     'OR' => [
-                        ['name' => ['!=', 'Management']],
-                        ['name' => null]
+                        ["$netport_table.name" => ['!=', 'Management']],
+                        ["$netport_table.name" => null]
                     ]
                 ]
             ] + $deleted_criteria
         ];
 
+        $so = $netport->rawSearchOptions();
+        foreach (Plugin::getAddSearchOptions(__CLASS__) as $key => $data) {
+            $so[] = ['id' => $key] + $data;
+        }
+
         $ports_iterator = $DB->request($criteria);
 
-        $so = $netport->rawSearchOptions();
         $dprefs = DisplayPreference::getForTypeUser(
             'Networkport',
             Session::getLoginUserID()
@@ -1151,7 +1156,7 @@ class NetworkPort extends CommonDBChild
 
                             $device1 = $netport->getItem();
 
-                            if (!$device1->can($device1->getID(), READ)) {
+                            if ($device1 === false || !$device1->can($device1->getID(), READ)) {
                                 break;
                             }
 
@@ -1276,7 +1281,36 @@ class NetworkPort extends CommonDBChild
                             }
                             break;
                         default:
-                            $output .= $port[$option['field']];
+                            if (
+                                isset($option["linkfield"])
+                                && isset($option['joinparams'])
+                            ) {
+                                $netport_table = $this->getTable();
+                                $already_link_tables = [];
+                                $join = Search::addLeftJoin(
+                                    __CLASS__,
+                                    $netport_table,
+                                    $already_link_tables,
+                                    $option["table"],
+                                    $option["linkfield"],
+                                    0,
+                                    0,
+                                    $option["joinparams"],
+                                    $option["field"]
+                                );
+                                $iterator = $DB->request([
+                                    'FROM'   => $netport_table,
+                                    'JOIN'   => [new QueryExpression($join)],
+                                    'WHERE'  => [
+                                        "$netport_table.id" => $port['id']
+                                    ]
+                                ]);
+                                foreach ($iterator as $row) {
+                                    $output .= $row[$option['field']];
+                                }
+                            } else {
+                                $output .= $port[$option['field']];
+                            }
                             break;
                     }
                 }
@@ -1404,6 +1438,11 @@ class NetworkPort extends CommonDBChild
         echo Html::input('name', ['value' => $this->fields['name']]);
         echo "</td></tr>\n";
 
+        echo "<tr class='tab_bg_1'><td>" . __('Alias') . "</td>\n";
+        echo "<td>";
+        echo Html::input('ifalias', ['value' => $this->fields['ifalias']]);
+        echo "</td></tr>\n";
+
         $instantiation = $this->getInstantiation();
         if ($instantiation !== false) {
             echo "<tr class='tab_bg_1'><th colspan='4'>" . $instantiation->getTypeName(1) . "</th></tr>\n";
