@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -701,14 +701,13 @@ class NotificationTarget extends CommonDBChild
 
         switch ($usertype) {
             case self::EXTERNAL_USER:
+            case self::GLPI_USER:
                 return $CFG_GLPI["url_base"] . "/index.php?redirect=$redirect";
 
-            case self::ANONYMOUS_USER:
-               // No URL
+            // case self::ANONYMOUS_USER:
+            default:
+                // No URL
                 return '';
-
-            case self::GLPI_USER:
-                return $CFG_GLPI["url_base"] . "/index.php?redirect=$redirect&noAUTO=1";
         }
     }
 
@@ -1750,7 +1749,7 @@ class NotificationTarget extends CommonDBChild
         }
 
         // Not all items support recursion
-        if (!$this->obj->maybeRecursive()) {
+        if (!($this->obj instanceof CommonDBTM)  || !$this->obj->maybeRecursive()) {
             return false;
         }
 
