@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -89,11 +89,6 @@ class PDU_Rack extends CommonDBRelation
     {
         $error_detected = [];
 
-        $pdus_id  = $this->fields['pdus_id'];
-        $racks_id = $this->fields['racks_id'];
-        $position = $this->fields['position'];
-        $side     = $this->fields['side'];
-
        //check for requirements
         if ($this->isNewItem()) {
             if (!isset($input['pdus_id'])) {
@@ -113,18 +108,10 @@ class PDU_Rack extends CommonDBRelation
             }
         }
 
-        if (isset($input['pdus_id'])) {
-            $pdus_id = $input['pdus_id'];
-        }
-        if (isset($input['racks_id'])) {
-            $racks_id = $input['racks_id'];
-        }
-        if (isset($input['position'])) {
-            $position = $input['position'];
-        }
-        if (isset($input['side'])) {
-            $side = $input['side'];
-        }
+        $pdus_id  = $input['pdus_id'] ?? $this->fields['pdus_id'] ?? null;
+        $racks_id = $input['racks_id'] ?? $this->fields['racks_id'] ?? null;
+        $position = $input['position'] ?? $this->fields['position'] ?? null;
+        $side     = $input['side'] ?? $this->fields['side'] ?? null;
 
         if (!count($error_detected)) {
            //check if required U are available at position
@@ -461,11 +448,11 @@ class PDU_Rack extends CommonDBRelation
                                 break;
                             case self::SIDE_TOP:
                                 echo "<i class='fa fa-arrow-up fa-fw'
-                                 title='" . __("On left") . "'></i>";
+                                 title='" . __("On top") . " (" . $current_pdu['position'] . ")'></i>";
                                 break;
                             case self::SIDE_BOTTOM:
                                 echo "<i class='fa fa-arrow-down fa-fw'
-                                 title='" . __("On left") . "'></i>";
+                                 title='" . __("On bottom") . " (" . $current_pdu['position'] . ")'></i>";
                                 break;
                         }
                     }
@@ -718,14 +705,16 @@ JAVASCRIPT;
     /**
      * Return an iterator for all used pdu in all racks
      *
-     * @return  Iterator
+     * @param array $fields_requested Fields to request
+     * @return DBmysqlIterator
      */
-    public static function getUsed()
+    public static function getUsed($fields_requested = ['*'])
     {
         /** @var \DBmysql $DB */
         global $DB;
 
         return $DB->request([
+            'SELECT' => $fields_requested,
             'FROM'  => self::getTable()
         ]);
     }
