@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -220,11 +220,11 @@ class RSSFeed extends CommonDBVisible implements ExtraVisibilityCriteria
         $it = new \DBmysqlIterator(null);
         $it->buildQuery($criteria);
         $sql = $it->getSql();
-        $sql = str_replace(
-            'SELECT * FROM ' . $DB->quoteName(self::getTable()) . ' ',
+        $sql = trim(str_replace(
+            'SELECT * FROM ' . $DB->quoteName(self::getTable()),
             '',
             $sql
-        );
+        ));
         return $sql;
     }
 
