@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -33,6 +33,8 @@
  * ---------------------------------------------------------------------
  */
 
+use Glpi\Event;
+
 /**
  * Reservation Class
  **/
@@ -115,9 +117,9 @@ class Reservation extends CommonDBChild
      **/
     public function prepareInputForUpdate($input)
     {
-       // Save fields
+        // Save fields
         $oldfields             = $this->fields;
-       // Needed for test already planned
+        // Needed for test already planned
         if (isset($input["begin"])) {
             $this->fields["begin"] = $input["begin"];
         }
@@ -129,7 +131,7 @@ class Reservation extends CommonDBChild
             return false;
         }
 
-       // Restore fields
+        // Restore fields
         $this->fields = $oldfields;
 
         return parent::prepareInputForUpdate($input);
@@ -163,7 +165,6 @@ class Reservation extends CommonDBChild
      **/
     public function prepareInputForAdd($input)
     {
-
        // Error on previous added reservation on several add
         if (isset($input['_ok']) && !$input['_ok']) {
             return false;
@@ -171,8 +172,8 @@ class Reservation extends CommonDBChild
 
        // set new date.
         $this->fields["reservationitems_id"] = $input["reservationitems_id"];
-        $this->fields["begin"]               = $input["begin"];
-        $this->fields["end"]                 = $input["end"];
+        $this->fields["begin"] = $input["begin"];
+        $this->fields["end"] = $input["end"];
 
         if (!$this->isReservationInputValid($input)) {
             return false;
@@ -181,6 +182,90 @@ class Reservation extends CommonDBChild
         return parent::prepareInputForAdd($input);
     }
 
+    public static function handleAddForm(array $input): void
+    {
+        if (empty($input['users_id'])) {
+            $input['users_id'] = Session::getLoginUserID();
+        }
+        if (!Session::haveRight("reservation", ReservationItem::RESERVEANITEM)) {
+            return;
+        }
+
+        Toolbox::manageBeginAndEndPlanDates($input['resa']);
+        if (!isset($input['resa']["begin"]) || !isset($input['resa']["end"])) {
+            return;
+        }
+
+        if (!isset($input['items']) || !is_array($input['items']) || count($input['items']) === 0) {
+            Session::addMessageAfterRedirect(
+                __('No selected items'),
+                false,
+                ERROR
+            );
+        }
+
+        $dates_to_add = [];
+        $dates_to_add[$input['resa']["begin"]] = $input['resa']["end"];
+        if (
+            isset($input['periodicity'])
+            && isset($input['periodicity']['type'])
+            && !empty($input['periodicity']['type'])
+        ) {
+            $dates_to_add += Reservation::computePeriodicities(
+                $input['resa']["begin"],
+                $input['resa']["end"],
+                $input['periodicity']
+            );
+        }
+        ksort($dates_to_add);
+
+        foreach ($input['items'] as $reservationitems_id) {
+            $rr = new self();
+            $group = (count($dates_to_add) > 1) ? $rr->getUniqueGroupFor($reservationitems_id) : null;
+
+            foreach ($dates_to_add as $begin => $end) {
+                $reservation_input = [
+                    'begin' => $begin,
+                    'end' => $end,
+                    'reservationitems_id' => $reservationitems_id,
+                    'comment' => $input['comment'],
+                    'users_id' => (int)$input['users_id'],
+                ];
+                if (count($dates_to_add) > 1) {
+                    $reservation_input['group'] = $group;
+                }
+
+                if ($newID = $rr->add($reservation_input)) {
+                    Event::log(
+                        $newID,
+                        "reservation",
+                        4,
+                        "inventory",
+                        sprintf(
+                            __('%1$s adds the reservation %2$s for item %3$s'),
+                            $_SESSION["glpiname"],
+                            $newID,
+                            $reservationitems_id
+                        )
+                    );
+
+                    $rri = new ReservationItem();
+                    $rri->getFromDB($reservationitems_id);
+                    $item = new $rri->fields["itemtype"]();
+                    $item->getFromDB($rri->fields["items_id"]);
+
+                    Session::addMessageAfterRedirect(
+                        sprintf(
+                            __('Reservation added for item %s at %s'),
+                            $item->getLink(),
+                            Html::convDateTime($reservation_input['begin'])
+                        )
+                    );
+                }
+            }
+        }
+    }
+
     /**
      * Check reservation input.
      *
@@ -480,6 +565,7 @@ class Reservation extends CommonDBChild
             Session::haveRight("reservation", ReservationItem::RESERVEANITEM)
             && count(self::getReservableItemtypes()) > 0
         ) ? "true" : "false";
+        $now = date("Y-m-d H:i:s");
         $js = <<<JAVASCRIPT
       $(function() {
          var reservation = new Reservations();
@@ -489,6 +575,7 @@ class Reservation extends CommonDBChild
             rand: $rand,
             license_key: '$scheduler_key',
             can_reserve: $can_reserve,
+            now: '$now',
          });
          reservation.displayPlanning();
       });
@@ -805,7 +892,8 @@ JAVASCRIPT;
             'min'        => 0,
             'max'        => 24 * HOUR_TIMESTAMP,
             'value'      => $default_delay,
-            'emptylabel' => __('Specify an end date')
+            'emptylabel' => __('Specify an end date'),
+            'allow_max_change' => false
         ]);
         echo "<br><div id='date_end$rand'></div>";
         $params = [
@@ -943,17 +1031,20 @@ JAVASCRIPT;
                             $begin_hour = $begin_time - strtotime(date('Y-m-d', $begin_time));
                             $end_hour   = $end_time - strtotime(date('Y-m-d', $end_time));
                             foreach ($options['days'] as $day => $val) {
+                                $end_day = $day;
+                                //Check that the start and end times are different else set the end day at the next day
+                                if ($begin_hour == $end_hour) {
+                                    $end_day = date('l', strtotime($day . ' +1 day'));
+                                }
                                 $dates[] = ['begin' => strtotime("next $day", $begin_time) + $begin_hour,
-                                    'end'   => strtotime("next $day", $end_time) + $end_hour
+                                    'end'   => strtotime("next $end_day", $end_time) + $end_hour
                                 ];
                             }
                         }
                     }
-
                     foreach ($dates as $key => $val) {
                         $begin_time = $val['begin'];
                         $end_time   = $val['end'];
-
                         while ($begin_time < $repeat_end) {
                             $toadd[date('Y-m-d H:i:s', $begin_time)] = date('Y-m-d H:i:s', $end_time);
                             $begin_time = strtotime('+1 week', $begin_time);
@@ -1013,7 +1104,6 @@ JAVASCRIPT;
                     break;
             }
         }
-
         return $toadd;
     }
 
@@ -1056,6 +1146,7 @@ JAVASCRIPT;
         if (isset($_REQUEST['defaultDate'])) {
             $defaultDate = $_REQUEST['defaultDate'];
         }
+        $now = date("Y-m-d H:i:s");
         $js = <<<JAVASCRIPT
       $(function() {
          var reservation = new Reservations();
@@ -1067,6 +1158,7 @@ JAVASCRIPT;
             currentv: 'listFull',
             defaultDate: '$defaultDate',
             license_key: '$scheduler_key',
+            now: '$now',
          });
          reservation.displayPlanning();
       });
