@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -124,7 +124,7 @@ class ReservationItem extends CommonDBChild
      * @param $itemtype   type of the item
      * @param $ID         ID of the item
      *
-     * @return true if succeed else false
+     * @return boolean true if succeed else false
      **/
     public function getFromDBbyItem($itemtype, $ID)
     {
@@ -1090,6 +1090,7 @@ class ReservationItem extends CommonDBChild
     private static function getAvailableItemsCriteria(string $itemtype): array
     {
         $reservation_table = ReservationItem::getTable();
+        /** @var CommonDBTM $item */
         $item = new $itemtype();
         $item_table = $itemtype::getTable();
 
@@ -1110,6 +1111,10 @@ class ReservationItem extends CommonDBChild
             ]
         ];
 
+        if ($item->isEntityAssign()) {
+            $criteria['WHERE'] += getEntitiesRestrictCriteria($item_table, '', '', $item->maybeRecursive());
+        }
+
         if ($item->maybeTemplate()) {
             $criteria['WHERE']["$item_table.is_template"] = 0;
         }
