@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -295,7 +295,7 @@ final class RichText
         ];
         $p = array_replace($p, $params);
 
-        $content_size = strlen($content);
+        $content_size = strlen($content ?? '');
 
        // Sanitize content first (security and to decode HTML entities)
         $content = self::getSafeHtml($content);
