@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -65,7 +65,7 @@ class SavedSearch_Alert extends CommonDBChild
 
        // can exists for template
         if (
-            ($item->getType() == 'SavedSearch')
+            ($item instanceof SavedSearch)
             && SavedSearch::canView()
         ) {
             $nb = 0;
@@ -107,7 +107,7 @@ class SavedSearch_Alert extends CommonDBChild
      *     - target for the Form
      *     - computers_id ID of the computer for add process
      *
-     * @return true if displayed  false if item not found or not right to display
+     * @return boolean true if displayed  false if item not found or not right to display
      **/
     public function showForm($ID, array $options = [])
     {
