@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2024 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -332,6 +332,24 @@ class SoftwareLicense extends CommonTreeDropdown
         return true;
     }
 
+    /**
+     * Is the license recursive ?
+     *
+     * @return boolean
+     **/
+    public function isRecursive()
+    {
+        $soft = new Software();
+        if (
+            isset($this->fields["softwares_id"])
+            && $soft->getFromDB($this->fields["softwares_id"])
+        ) {
+            return $soft->isRecursive();
+        }
+
+        return false;
+    }
+
 
     public function rawSearchOptions()
     {
@@ -467,6 +485,15 @@ class SoftwareLicense extends CommonTreeDropdown
             'datatype'           => 'text'
         ];
 
+        $tab[] = [
+            'id'                 => '121',
+            'table'              => $this->getTable(),
+            'field'              => 'date_creation',
+            'name'               => __('Creation date'),
+            'datatype'           => 'datetime',
+            'massiveaction'      => false
+        ];
+
         $tab[] = [
             'id'                 => '24',
             'table'              => 'glpi_users',
@@ -1191,10 +1218,12 @@ class SoftwareLicense extends CommonTreeDropdown
     public function showDebug()
     {
 
-        $license = ['softname' => '',
-            'name'     => '',
-            'serial'   => '',
-            'expire'   => ''
+        $license = [
+            'softname'      => '',
+            'name'          => '',
+            'serial'        => '',
+            'expire'        => '',
+            'entities_id'   => '',
         ];
 
         $options['entities_id'] = $this->getEntityID();
@@ -1224,8 +1253,8 @@ class SoftwareLicense extends CommonTreeDropdown
 
         if (!$withtemplate) {
             $nb = 0;
-            switch ($item->getType()) {
-                case 'Software':
+            switch (get_class($item)) {
+                case Software::class:
                     if (!self::canView()) {
                         return '';
                     }
@@ -1236,8 +1265,8 @@ class SoftwareLicense extends CommonTreeDropdown
                         self::getTypeName(Session::getPluralNumber()),
                         (($nb >= 0) ? $nb : '&infin;')
                     );
-                break;
-                case 'SoftwareLicense':
+
+                case SoftwareLicense::class:
                     if (!self::canView()) {
                         return '';
                     }
@@ -1251,7 +1280,6 @@ class SoftwareLicense extends CommonTreeDropdown
                         self::getTypeName(Session::getPluralNumber()),
                         (($nb >= 0) ? $nb : '&infin;')
                     );
-                break;
             }
         }
         return '';
